@@ -5,27 +5,28 @@
 
 /*  Common dbm access routines */
 
-#include <errno.h>
 #include <stdio.h>
 #include <errno.h>
 #include <ndbm.h>
 
 #include "cstuff.h"
 
-int database_delete(DBM *db, scheme_value key)
+extern int errno;
+
+int database_delete(DBM *db, s48_value key)
 {
     datum work_key;
     work_key.dptr = ADDRESS_AFTER_HEADER(key, char);
-    work_key.dsize = STRING_LENGTH(key);
+    work_key.dsize = S48_STRING_LENGTH(key);
     return(dbm_delete(db, work_key));
     }
 
-char *database_fetch(DBM *db, scheme_value key)
+char *database_fetch(DBM *db, s48_value key)
 {
     datum work_key, work_data;
     char *work_string;
     work_key.dptr = ADDRESS_AFTER_HEADER(key, char);
-    work_key.dsize = STRING_LENGTH(key);
+    work_key.dsize = S48_STRING_LENGTH(key);
     work_data = dbm_fetch(db, work_key);
     if (work_data.dptr == NULL)
 	{
@@ -41,13 +42,13 @@ char *database_fetch(DBM *db, scheme_value key)
     return(work_string);
     }
 
-int database_store(DBM *db, scheme_value key, scheme_value data, int flags)
+int database_store(DBM *db, s48_value key, s48_value data, int flags)
 {
     datum work_key, work_data;
     work_key.dptr = ADDRESS_AFTER_HEADER(key, char);
-    work_key.dsize = STRING_LENGTH(key);
+    work_key.dsize = S48_STRING_LENGTH(key);
     work_data.dptr = ADDRESS_AFTER_HEADER(data, char);
-    work_data.dsize = STRING_LENGTH(data);
+    work_data.dsize = S48_STRING_LENGTH(data);
     return(dbm_store(db, work_key, work_data, flags));
     }
 
