@@ -367,7 +367,7 @@ sch_syslog(s48_value sch_level, s48_value sch_opt_facility,
 
   if (!syslog_open)
     s48_raise_string_os_error("syslog isn't open");
-  syslog(facility | level, s48_extract_string (sch_message));
+  syslog(facility | level, "%s", s48_extract_string (sch_message));
   return S48_UNSPECIFIC;
 }
 
